function [x, k] = solvGasSei(A,b,inix,GTol)
%solvGasSei.m Gauss-Seidel 法
% Gauss-Seidel 法による行列方程式 Ax = b の解法
% 書式：[x,k] = solvGasSei(A,b,inix,GTol)
% 入力引数
% A：正方行列 係数行列
% b：縦ベクトル 定数ベクトル
% inix：縦ベクトル 解の初期値
% GTol：スカラー 計算精度 空行列はデフォルト値（1e-5）
% 出力（戻り値）
% x：縦ベクトル 解ベクトル
% k：スカラー 収束回数
    [M,N] = size(A);
    % パラメーターのエラーチェック
    if (M ~= N) % エラー：正方行列のチェック
        x = []; k = NaN;
        return;
    end
    dA = diag(A);
    if ~all(dA) % エラー：対角要素のチェック
        x = []; k = -inf;
        return;
    end
    if isempty(GTol)
        GTol = 1e-5; % デフォルトの計算精度
    end
    n = length(b); x = inix; k = 0;
    dX = ones(n,1);
    while (norm(dX) / norm(x)) > GTol
        for i = 1:n
            dX(i) = b(i) ./ dA(i);
            dX(i) = dX(i) - A(i,:)*x./dA(i);
            x(i) = x(i) + dX(i);
            k = k + 1;
        end
    end
end