function [x,k] = solvIteration(Method,A,b,inix,Tol)
%solvIteration.m
% 反復法 (Jacobi 法または Gauss-Seidel 法 ) による行列方程式の解法
% 反復アルゴリズムの選択は文字列引数で選択する．
% 使用するアルゴリズム
% Jacobi 法 ： solvJacobi() 関数
% Gauss-Seidel 法 ： solvGasSei() 関数
% 書式：[x,k] = solvIteration (Method,A,b,inix,Tol)
% 入力引数
% Method：文字列 アルゴリズム名 jacobi=Jacobi 法 /
% gauss=Gauss-Seidel 法
% A：正方行列 係数行列
% b：縦ベクトル 定数ベクトル
% inix：縦ベクトル 解の初期値
% Tol：スカラー 計算精度 空行列はデフォルト値（1e-5）
% 出力（戻り値）
% x：縦ベクトル 解ベクトル
% k：スカラー 収束回数
    if isempty(Tol)
        Tol = 1e-5; % デフォルトの計算精度
    end
    arg = lower(Method); % 小文字に変換
    switch arg
    case 'jacobi' % Running Jacobi Method
                [x,k]=solvJacobi(A,inix,b,Tol);
    case 'gauss' % Running Gauss-Seidel Method
                [x,k]=solvGasSei(A,b,inix,Tol);
    otherwise
                disp('unkown Argorizum'); 
    end
end
