function [x,k]=solvJacobi(A,inix,b,JTol)
% Jacobi Method のテスト関数 M- ファイル
% Ax = b の行列方程式の解を Jacobi 法を使って解を求める．
% 書式：[x,k] = solvJacobi(A,inix,b,JTol);
% A： 正方行列 係数行列
% inix：縦ベクトル 解ベクトルの初期値
% b： 縦ベクトル 定数ベクトル
% JTol：スカラー 計算精度 空行列指定時はデフォルト値（1e-5）
% 出力（戻り値）
% x： 縦ベクトル 解ベクトル
% k： スカラー 繰り返し数
    [M,N] = size(A);
    if (M ~= N) % エラー：正方行列のチェック
        x = []; k = NaN;
        return;
    end
    dA = diag(A);
    if ~all(dA) % エラー：対角要素のチェック
        x = []; k = -inf;
        return;
    end
    if isempty(JTol)
        JTol = 1e-5; % デフォルトの計算精度 後で確認
    end
    invD = (dA .^ -1); % 対角要素の逆数
    dX = inix; x = inix; % 初期値のセット
    k = 0; % ループ回数
    while (norm(dX)/norm(x)) > JTol % 収束条件
        dX = (b-A*x).*invD; % Jacobi Method
        x = x + dX;
        k = k + 1;
    end
end
