function [x, xstate] = solvMatrix(A,b)
% Ax = b における行列方程式の解法（solvMatrix.m）
% 関数書式：[x, xstate] = solvMatrix(A,b)
% 入力引数
% A：正方行列 係数行列
% b：縦ベクトル 定数項ベクトル
% 出力（戻り値）
% x：縦ベクトル 解ベクトル
% xstate：変数 解の状態
% 特記事項：
% 戻り値の x，xstate の内容
% x = [] xstate = NaN 解が存在しない
% x = 縦ベクトル xstate = inf 一意の解が存在しない
% x = 縦ベクトル xstate = [] 一意の解
  [m,n] = size(A); % 係数行列のサイズチェック
  if m ~= n
   x = [];
   xstate = ' 行列 A は正方行列である必要があります ';
   return;
  end
  rA = rank(A); rAb = rank([A b]);
  if rA ~= rAb % 解の存在のチェック
    x = []; xstate = NaN; % 解は存在しない
  else
    x = A \ b;
    if rAb < m % 解の一意性のチェック
      xstate = inf; % 一意の解が存在しない
    else
      xstate = []; % 一意の解
    end
 end
end
