function s = areaInt(f,x)
%s = areaInt(f,x)   増分一定の積分計算
%   被積分関数 f を積分区間 w で積分を計算
%   被積分関数f：関数ハンドルまたは関数名の文字列
%   積分区間w：等間隔な積分区間ベクトル
%             実数のベクトルを想定(想定以外の動作は不定)

    % 関数名チェック
    if isa(f,"function_handle")
        func = f;               % 関数ハンドル
    elseif isstring(f) || ischar(f)
        func = str2func(f);     % 関数ハンドルへ変換
    end
    [m,n] = size(x);
    lng = max(m,n); dx = x(2)-x(1); % 増分
    t = ones(lng,1)*dx;             % 縦ベクトル
    try
        y = func(x);            % 関数値（長辺）
    catch                       % 計算不可の処理
        error('第1引数には認識可能な関数名を指定してください');
    end
    s = y*t;        % 積分の長方形近似
    % draw integration results and grahis in figure
    txty = max(y)/2;    txtx = max(x)/2;
    figure;
    plot(x,y);grid on
    text(txtx,txty,['Integral result =',num2str(s)]);
end
