function varargout = rom_int(a,b,func,N)
% Romberg Quard：ロンバーグ積分による求積関数
% [R,TableSize] = rom_int(a,b,func,N)
% 入力
% a,b 積分区間
% func 被積分関数の名前を示す文字列
% この関数は func(x) という形式で呼び出される
% N ロンバーグ表の行および列の数
% 出力
% R ロンバーグ表．R(N,N) が最も高精度の積分値
% 単独の戻り値の場合はロンバーグ積分値
% TblSize ロンバーグ表のサイズ（オプション）
% このオプションを指定することにより，戻り値 R が
% ロンバーグ表になる．

    if isa(func,"string")||isa(func,"char") % 関数名が文字列？
        fh = str2func(func); % 関数ハンドルへの変換
    elseif isa(func,"function_handle")
        fh = func;
    end
    R = zeros(N,N); % ロンバーグ表の初期化
    % もっとも「粗い」項 R(1,1) を計算
    h = b - a; % 最も「粗い」台形の幅
    np = 1; % 台形の数の現在値
    R(1,1) = h * (fh(a) + fh(b)) / 2;
    % 所望の行数 i = 2,・・・,N について，以下の手順を繰り返す
    for i = 2:N
        % 漸近形台形公式の和の部分の計算
        h = h / 2; % 台形の幅を半分にする
        np = 2*np; % 台形の数は 2 倍
        sumT = 0;
        for k = 1:2:np-1    %このループはk=1,3,5,...,np-1
            sumT = sumT + fh(a+k*h);
        end
        %ロンバーグ表R(i,1),...,R(i,i)を計算
        R(i,1) = 1/2 * R(i-1,1) + h*sumT;
        m = 1;
        for j = 2:i
            m = 4*m;
            R(i,j) = R(i,j-1) + (R(i,j-1)-R(i-1,j-1)) / (m-1);
        end
    end
    % 戻り値の設定
    if 1 == nargout % 戻り値が 1 変数のとき
        varargout{1} = R(N,N);
    elseif 2 == nargout % 戻り値が 2 変数の場合
        varargout{1} = R;
        varargout{2} = N;
    end
end 
